#ifndef NT2_INCLUDE_FUNCTIONS_LOGICAL_NOTOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGICAL_NOTOR_HPP_INCLUDED

#include <nt2/boolean/include/functions/logical_notor.hpp>

#endif
